"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.desc = exports.command = void 0;

var _split = _interopRequireDefault(require("split2"));

var _chalk = _interopRequireDefault(require("chalk"));

var _prettyjson = _interopRequireDefault(require("prettyjson"));

var _utilities = require("./utilities");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const command = 'pretty-print';
exports.command = command;
const desc = 'Format logs for user-inspection.';
/* eslint-disable quote-props */

exports.desc = desc;
const logLevels = {
  '10': 'TRACE',
  '20': 'DEBUG',
  '30': 'INFO',
  '40': 'WARN',
  '50': 'ERROR',
  '60': 'FATAL'
};
/* eslint-enable */

const logLevelColorMap = {
  DEBUG: _chalk.default.gray,
  ERROR: _chalk.default.red,
  FATAL: _chalk.default.red,
  INFO: _chalk.default.cyan,
  TRACE: _chalk.default.gray,
  WARN: _chalk.default.yellow
};

const getLogLevelName = logLevel => {
  return logLevels[logLevel] || 'INFO';
};

const createLogFormatter = configuration => {
  const stream = (0, _split.default)(line => {
    if (!(0, _utilities.isRoarrLine)(line)) {
      return configuration.excludeOrphans ? '' : line + '\n';
    }

    const message = JSON.parse(line);
    let formattedMessage = '';
    formattedMessage = '[' + new Date(message.time).toISOString() + ']';

    if (message.context.logLevel && typeof message.context.logLevel === 'number') {
      const logLevelName = getLogLevelName(message.context.logLevel);
      const logLevelColorName = logLevelColorMap[logLevelName];

      if (!logLevelColorName) {
        throw new Error('Unexpected state.');
      }

      formattedMessage += ' ' + logLevelColorName(logLevelName + ' (' + message.context.logLevel + ')');
    }

    if (message.context.package) {
      formattedMessage += ' (@' + message.context.package + ')';
    }

    if (message.context.namespace) {
      formattedMessage += ' (#' + message.context.namespace + ')';
    }

    formattedMessage += ': ' + message.message + '\n';

    if (configuration.includeContext && message.context) {
      /* eslint-disable no-unused-vars */
      const {
        application: tmp0,
        hostname: tmp1,
        instanceId: tmp2,
        logLevel: tmp3,
        namespace: tmp4,
        package: tmp5,
        package: tmp6,
        ...rest
      } = message.context;
      /* eslint-enable */

      if (Object.keys(rest).length) {
        // eslint-disable-next-line no-console
        formattedMessage += _prettyjson.default.render(rest) + '\n\n';
      }
    }

    return formattedMessage;
  });
  return stream;
}; // eslint-disable-next-line flowtype/no-weak-types


const builder = yargs => {
  return yargs.options({
    'exclude-orphans': {
      default: false,
      describe: 'Excludes messages that cannot be recognized as Roarr log message.',
      type: 'boolean'
    },
    'include-context': {
      default: true,
      type: 'boolean'
    }
  });
};

exports.builder = builder;

const handler = argv => {
  process.stdin.pipe(createLogFormatter(argv)).pipe(process.stdout);
};

exports.handler = handler;
//# sourceMappingURL=pretty-print.js.map